==> todotask2.0.1.zip: todotask2/app/views/common/loginbar.inc.php <==
<?php
if (!isset($loginuser)||$loginuser=="") $loginuser = CONST_GESTNAME;
if (!isset($group_no)) $group_no = "";
if (!isset($grpmail_flg)) $grpmail_flg = VIEW_OFF;


$welcomemsg = "";
if (rand(1,50)<50){
	$welcomemsg = "ようこそ";
} else {
	$welcomemsg = "仕事は順調ですか？";
}

 

// 未ログイン状態
if ($loginuser == CONST_GESTNAME){
?>
	<table border="0" cellpadding="0" cellspacing="0" width="98%">
	<tr><td align="left" width="460">
	<?php echo $welcomemsg . "&nbsp;" . $loginuser; ?>さん</td>
	<td align="right">
	<a href="<?php echo ROOT_URL; ?>">トップ</a>　
	<a href="<?php echo ROOT_URL; ?>userlogin.php?group_no=<?php echo $group_no; ?>">ログイン</a>　
	<a href="<?php echo ROOT_URL; ?>usermst.php">ユーザー登録</a>　
	</td></tr>
	</table>
<?php
// ログイン済み
} else {
?>
	<table border="0" cellpadding="0" cellspacing="0" width="98%">
	<tr><td align="left">
	<?php echo $loginuser; ?>さん でログインしています。</td>
	<td align="right">
	<a href="<?php echo ROOT_URL; ?>index.php">トップ</a>　
	<a href="<?php echo ROOT_URL; ?>usermst.php?mode=upd">ユーザ情報</a>　

<?php
	// 特定のグループを表示している
	if ($group_no != "") {
		if (isset($mbMemberFlg)) {
			// そのタスクグループに参加していないとき
			if ($mbMemberFlg==GRPAUTH_NOMEM) {
?>
			<a href="<?php echo ROOT_URL; ?>grpjoin.php?group_no=<?php echo $group_no; ?>">グループに参加申請する</a>　
<?php
			// メンバー
			} else if ($mbMemberFlg >= GRPAUTH_MEM) {

			 	// ログを記録するモードである場合
				if (LOG_ACT==LOG_ACT_ON) {
?>
					<a href="<?php echo ROOT_URL; ?>loglist.php?group_no=<?php echo $group_no; ?>">グループ履歴</a>　
<?php
				}

				// 管理権限を持っている。
				if (($mbMemberFlg==GRPAUTH_ADMIN)||($mbMemberFlg==GRPAUTH_MADMIN)){
?>
					<a href="<?php echo ROOT_URL; ?>grpmst.php?group_no=<?php echo $group_no; ?>">グループ管理</a>　
<?php
				}

				// グループ同報メール
				if (($grpmail_flg == VIEW_ON && MAIL_GRPMAIL)){
?>
					<a href="<?php echo ROOT_URL; ?>grpmail.php?group_no=<?php echo $group_no; ?>&mode=<?php echo GRPMAIL_MODE_BROADCAST; ?>">メッセージを送る</a>　
<?php
				}

				// このグループへ招待する
?>
					<a href="<?php echo ROOT_URL; ?>grpmail.php?group_no=<?php echo $group_no; ?>&mode=<?php echo GRPMAIL_MODE_SOLICIT; ?>">グループへ招待する</a>　
<?php

			}
		}
	}
?>
	<a href="<?php echo ROOT_URL; ?>userlogin.php">ログアウト</a>
	</td></tr>
	</table>
<?php
}
?>

==> todotask2.1.4.zip: todotask2/app/views/common/loginbar.inc.php <==
<?php
if (!isset($loginuser)||$loginuser=="") $loginuser = CONST_GESTNAME;
if (!isset($group_no)) $group_no = "";
if (!isset($grpmail_flg)) $grpmail_flg = VIEW_OFF;


$welcomemsg = "";
if (rand(1,50)<50){
	$welcomemsg = "ようこそ";
} else {
	$welcomemsg = "仕事は順調ですか？";
}

 

// 未ログイン状態
if ($loginuser == CONST_GESTNAME){
?>
	<table border="0" cellpadding="0" cellspacing="0" width="98%">
	<tr><td align="left" width="460">
	<?php echo $welcomemsg . "&nbsp;" . $loginuser; ?>さん</td>
	<td align="right">
	<a href="<?php echo ROOT_URL; ?>">トップ</a>　
<?php
	$buf_domain = ROOT_URL;
	if (ACTIVE_SSL) {
		$buf_domain = SSL_ROOT_URL;
	}
?>
	<a href="<?php echo $buf_domain; ?>userlogin.php?group_no=<?php echo $group_no; ?>">ログイン</a>　
	<a href="<?php echo ROOT_URL; ?>usermst.php">ユーザー登録</a>　
	</td></tr>
	</table>
<?php
// ログイン済み
} else {
?>
	<table border="0" cellpadding="0" cellspacing="0" width="98%">
	<tr><td align="left">
	<?php echo $loginuser; ?>さん でログインしています。</td>
	<td align="right">
	<a href="<?php echo ROOT_URL; ?>index.php">トップ</a>　
	<a href="<?php echo ROOT_URL; ?>usermst.php?mode=upd">ユーザ情報</a>　

<?php
	// 特定のグループを表示している
	if ($group_no != "") {
		if (isset($mbMemberFlg)) {
			// そのタスクグループに参加していないとき
			if ($mbMemberFlg==GRPAUTH_NOMEM) {
?>
			<a href="<?php echo ROOT_URL; ?>grpjoin.php?group_no=<?php echo $group_no; ?>">グループに参加申請する</a>　
<?php
			// メンバー
			} else if ($mbMemberFlg >= GRPAUTH_MEM) {

			 	// ログを記録するモードである場合
				if (LOG_ACT==LOG_ACT_ON) {
?>
					<a href="<?php echo ROOT_URL; ?>loglist.php?group_no=<?php echo $group_no; ?>">グループ履歴</a>　
<?php
				}

				// 管理権限を持っている。
				if (($mbMemberFlg==GRPAUTH_ADMIN)||($mbMemberFlg==GRPAUTH_MADMIN)){
?>
					<a href="<?php echo ROOT_URL; ?>grpmst.php?group_no=<?php echo $group_no; ?>">グループ管理</a>　
<?php
				}

				// グループ同報メール
				if (($grpmail_flg == VIEW_ON && MAIL_GRPMAIL)){
?>
					<a href="<?php echo ROOT_URL; ?>grpmail.php?group_no=<?php echo $group_no; ?>&mode=<?php echo GRPMAIL_MODE_BROADCAST; ?>">メッセージを送る</a>　
<?php
				}

				// このグループへ招待する
?>
					<a href="<?php echo ROOT_URL; ?>grpmail.php?group_no=<?php echo $group_no; ?>&mode=<?php echo GRPMAIL_MODE_SOLICIT; ?>">グループへ招待する</a>　
<?php

			}
		}
	}
?>
	<a href="<?php echo ROOT_URL; ?>userlogin.php">ログアウト</a>
	</td></tr>
	</table>
<?php
}
?>
